@@ -9,6 +9,6 @@ colors = Fore
 
 class coloredPrint():
     def print(self, textToPrint, color=None):
-        if (color == None or not color in colors):
-            raise ValueError("Invalid Color")
+        if (color == None):
+            raise ValueError(f"{colors.RED}Color can't be None{colors.RESET}")
         print(f"{color}{textToPrint}{colors.RESET}")
